<img src="https://emojipedia-us.s3.dualstack.us-west-1.amazonaws.com/thumbs/240/apple/285/rocket_1f680.png" alt="Apple Releases Logo" title="Rocket" align="right" height="60"/>

# Radium

[![License](https://img.shields.io/github/license/ja1dan/Radium)](https://github.com/ja1dan/Radium/blob/master/LICENSE)
[![Stars](https://img.shields.io/github/stars/ja1dan/Radium)](https://github.com/ja1dan/Radium/stargazers)
[![LoC](https://img.shields.io/tokei/lines/github/ja1dan/Radium)](https://github.com/ja1dan/Radium)

Supercharge the Python logging module.  
Created with love by [Jaidan](https://github.com/ja1dan).